@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: File.h 2272 2006-12-17 10:21:48Z svn $
+ * $Id: File.h 2294 2006-12-23 18:25:41Z svn $
  *****************************************************************************/
 
 #ifndef FILE_H
@@ -48,7 +48,6 @@
 #include "Auxiliary.h"
 #include "Macro.h"
 
-using namespace std;
 
 #ifdef DEBUG
 #define REQUIRE_FILE_OPENDED                                    \
@@ -156,7 +155,7 @@ public:
 
         if (apr_file_open(&file_, file_path_, flag, APR_OS_DEFAULT,
                           pool_) != APR_SUCCESS) {
-            throw apr_pstrcat(pool_,
+            apr_pstrcat(pool_,
                               MESSAGE_FILE_OPEN_FAILED,
                               " [", file_path_, "]",
                               " (" __FILE__ ":" APR_STRINGIFY(__LINE__) ")",
