@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: TemplateParser.cpp 2035 2006-11-23 16:14:21Z svn $
+ * $Id: TemplateParser.cpp 2291 2006-12-22 14:07:00Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -32,6 +32,11 @@
 
 #include "TemplateParser.h"
 #include "Message.h"
+#include "SourceInfo.h"
+
+using namespace std;
+
+SOURCE_INFO_ADD("$Id: TemplateParser.cpp 2291 2006-12-22 14:07:00Z svn $");
 
 #define AS_NODE(pointer)            reinterpret_cast<node_t *>(pointer)
 #define AS_UNCONST_NODE(pointer)    const_cast<node_t *>(pointer)
