@@ -1,5 +1,7 @@
 #!/usr/bin/env zsh
 
+unsetopt FUNCTION_ARGZERO
+
 echo -n 'windows pass: '
 read -s WIN_PASS
 echo
@@ -20,7 +22,10 @@ run ./util/win_build.pl
 run make -f GNUmakefile.dist dist-sf
 run make -f GNUmakefile.dist dist-win-sf
 
-pushd doc
-run make doc-update
-run cp apache.htm apache-win.htm /home/apache/mod_uploader/
-popd
+(
+    cd doc
+    run make doc-update
+    run cp apache.htm apache-win.htm /home/apache/mod_uploader/
+);
+
+echo -e "\033[1;32mOK\033[0m";
